intelmq.bots.experts.tor_nodes package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.tor_nodes package

## Submodules

## intelmq.bots.experts.tor_nodes.expert module

See README for database download.

`intelmq.bots.experts.tor_nodes.expert.` `BOT`

  alias of `intelmq.bots.experts.tor_nodes.expert.TorExpertBot`

class `intelmq.bots.experts.tor_nodes.expert.` `TorExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Check if the IP address is a Tor Exit Node based on a local database of TOR nodes

  `database`: str = '/opt/intelmq/var/lib/bots/tor_nodes/tor_nodes.dat'
  `init`()
  `overwrite`: bool = False
  `process`()
  classmethod `run`(parsed_args=None)
  classmethod `update_database`()

## Module contents